@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Acme::MetaSyntactic::MultiList;
 our @ISA = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 =encoding iso-8859-1
 
@@ -17,6 +17,10 @@ This theme has the nobel prize winners, divided into categories. The
 first Nobel prizes were awarded in 1901. Nobel prizes have been awarded
 for Chemistry, Literature, Medicine, Peace, Physics, and Economics.
 
+Strictly speaking, the Economics prize is not actually a "Nobel Prize",
+but the "I<Sveriges Riksbank Prize in Economic Sciences in Memory of
+Alfred Nobel>". It was first awarded in 1969.
+
 The winners are:
 
 =cut
@@ -1047,6 +1051,13 @@ Abigail
 
 =item *
 
+2013-12-09 - v1.002
+
+Updated to state that the Econimics prize is not strictly a Nobel prize, and
+published in Acme-MetaSyntactic-Themes version 1.038.
+
+=item *
+
 2013-10-13 - v1.001
 
 Updated with the Nobel prizes for 2013, and
